@@ -72,6 +72,27 @@ describe('Promisify function', function () {
         expect(() => Gio._promisify(Gio.Subprocess.prototype, 'communicate_utf8_async', 'commuicate_utf8_finish')).toThrowError(/commuicate_utf8_finish/);
     });
 
+    it('promisifies functions', async function () {
+        Gio._promisify(Gio.File.prototype, 'query_info_async');
+        const file = Gio.File.new_for_path('.');
+
+        const fileInfo = await file.query_info_async(Gio.FILE_ATTRIBUTE_STANDARD_TYPE,
+            Gio.FileQueryInfoFlags.NONE, GLib.PRIORITY_DEFAULT, null);
+        expect(fileInfo.get_file_type()).not.toBe(Gio.FileType.UNKNOWN);
+    });
+
+    it('preserves old behavior', function (done) {
+        Gio._promisify(Gio.File.prototype, 'query_info_async');
+        const file = Gio.File.new_for_path('.');
+
+        file.query_info_async(Gio.FILE_ATTRIBUTE_STANDARD_TYPE,
+            Gio.FileQueryInfoFlags.NONE, GLib.PRIORITY_DEFAULT, null, (_, res) => {
+                const fileInfo = file.query_info_finish(res);
+                expect(fileInfo.get_file_type()).not.toBe(Gio.FileType.UNKNOWN);
+                done();
+            });
+    });
+
     it('can guess the finish function', function () {
         expect(() => Gio._promisify(Gio._LocalFilePrototype, 'read_async')).not.toThrow();
         expect(() => Gio._promisify(Gio.DBus, 'get')).not.toThrow();
@@ -290,3 +311,33 @@ describe('Gio.add_action_entries override', function () {
         expect(() => app.add_action_entries(entries)).toThrow();
     });
 });
+
+describe('Gio.FileEnumerator overrides', function () {
+    it('iterates synchronously', function () {
+        const dir = Gio.File.new_for_path('.');
+        let count = 0;
+        for (const value of dir.enumerate_children(
+            'standard::name',
+            Gio.FileQueryInfoFlags.NOFOLLOW_SYMLINKS,
+            null
+        )) {
+            expect(value).toBeInstanceOf(Gio.FileInfo);
+            count++;
+        }
+        expect(count).toBeGreaterThan(0);
+    });
+
+    it('iterates asynchronously', async function () {
+        const dir = Gio.File.new_for_path('.');
+        let count = 0;
+        for await (const value of dir.enumerate_children(
+            'standard::name',
+            Gio.FileQueryInfoFlags.NOFOLLOW_SYMLINKS,
+            null
+        )) {
+            expect(value).toBeInstanceOf(Gio.FileInfo);
+            count++;
+        }
+        expect(count).toBeGreaterThan(0);
+    });
+});
