@@ -417,23 +417,30 @@ function* _listModelIterator() {
         yield this.get_item(_index++);
 }
 
-function _promisify(proto, asyncFunc,
-    finishFunc = `${asyncFunc.replace(/_(begin|async)$/, '')}_finish`) {
+function _promisify(proto, asyncFunc, finishFunc = undefined) {
     if (proto[asyncFunc] === undefined)
         throw new Error(`${proto} has no method named ${asyncFunc}`);
 
+    if (finishFunc === undefined) {
+        if (asyncFunc.endsWith('_begin') || asyncFunc.endsWith('_async'))
+            finishFunc = `${asyncFunc.slice(0, -5)}finish`;
+        else
+            finishFunc = `${asyncFunc}_finish`;
+    }
+
     if (proto[finishFunc] === undefined)
         throw new Error(`${proto} has no method named ${finishFunc}`);
 
-    if (proto[`_original_${asyncFunc}`] !== undefined)
+    const originalFuncName = `_original_${asyncFunc}`;
+    if (proto[originalFuncName] !== undefined)
         return;
-    proto[`_original_${asyncFunc}`] = proto[asyncFunc];
+    proto[originalFuncName] = proto[asyncFunc];
     proto[asyncFunc] = function (...args) {
-        if (!args.every(arg => typeof arg !== 'function'))
-            return this[`_original_${asyncFunc}`](...args);
+        if (args.length === this[originalFuncName].length)
+            return this[originalFuncName](...args);
         return new Promise((resolve, reject) => {
-            const callStack = new Error().stack.split('\n').filter(line => !line.match(/promisify/)).join('\n');
-            this[`_original_${asyncFunc}`](...args, function (source, res) {
+            let {stack: callStack} = new Error();
+            this[originalFuncName](...args, function (source, res) {
                 try {
                     const result = source !== null && source[finishFunc] !== undefined
                         ? source[finishFunc](res)
@@ -442,6 +449,8 @@ function _promisify(proto, asyncFunc,
                         result.shift();
                     resolve(result);
                 } catch (error) {
+                    callStack = callStack.split('\n').filter(line =>
+                        line.indexOf('_promisify/') === -1).join('\n');
                     if (error.stack)
                         error.stack += `### Promise created here: ###\n${callStack}`;
                     else
@@ -536,6 +545,66 @@ function _init() {
         return this.replace_contents_bytes_async(contents, etag, make_backup, flags, cancellable, callback);
     };
 
+    Gio.FileEnumerator.prototype[Symbol.iterator] = function* FileEnumeratorIterator() {
+        while (true) {
+            try {
+                const info = this.next_file(null);
+                if (info === null)
+                    break;
+                yield info;
+            } catch (err) {
+                this.close(null);
+                throw err;
+            }
+        }
+        this.close(null);
+    };
+
+    Gio.FileEnumerator.prototype[Symbol.asyncIterator] = async function* AsyncFileEnumatorIterator() {
+        const self = this;
+
+        function next() {
+            return new Promise((resolve, reject) => {
+                self.next_files_async(1, Gio.PRIORITY_DEFAULT, null, (_self, res) => {
+                    try {
+                        const files = self.next_files_finish(res);
+                        resolve(files.length === 0 ? null : files[0]);
+                    } catch (err) {
+                        reject(err);
+                    }
+                });
+            });
+        }
+
+        function close() {
+            return new Promise((resolve, reject) => {
+                self.close_async(Gio.PRIORITY_DEFAULT, null, (_self, res) => {
+                    try {
+                        resolve(self.close_finish(res));
+                    } catch (err) {
+                        reject(err);
+                    }
+                });
+            });
+        }
+
+        while (true) {
+            try {
+                // eslint-disable-next-line no-await-in-loop
+                const info = await next();
+                if (info === null)
+                    break;
+                yield info;
+            } catch (err) {
+                // eslint-disable-next-line no-await-in-loop
+                await close();
+                throw err;
+            }
+        }
+
+        return close();
+    };
+
     // Override Gio.Settings and Gio.SettingsSchema - the C API asserts if
     // trying to access a nonexistent schema or key, which is not handy for
     // shell-extension writers
